@@ -38,6 +38,7 @@ class Config:
     SECTION_JWT = 'jwt'
     SECTION_CORE_API = 'core-api'
     SECTION_VOUCH = 'vouch'
+    SECTION_DATABASE = 'database'
 
     # Runtime parameters
     REST_PORT = 'rest-port'
@@ -48,11 +49,15 @@ class Config:
     PROJECT_NAMES_IGNORE_LIST = 'project-names-ignore-list'
     ROLES_LIST = 'roles-list'
     ALLOWED_SCOPES = 'allowed-scopes'
+    MAX_LLT_CNT_PER_PROJECT = 'max-llt-count-per-project'
+    FACILITY_OPERATOR_ROLE = 'facility-operators-role'
+    LLT_ROLE_SUFFIX = 'llt-role-suffix'
 
     # Logging Parameters
     LOGGER = 'logger'
     LOG_DIR = 'log-directory'
     LOG_FILE = 'log-file'
+    METRICS_LOG_FILE = 'metrics-log-file'
     LOG_RETAIN = 'log-retain'
     LOG_SIZE = 'log-size'
     LOG_LEVEL = 'log-level'
@@ -78,6 +83,12 @@ class Config:
     JWT_PRIVATE_KEY = 'jwt-private-key'
     JWT_PRIVATE_KEY_PASS_PHRASE = 'jwt-pass-phrase'
 
+    # Database Parameters
+    DB_USER = "db-user"
+    DB_PASSWORD = "db-password"
+    DB_NAME = "db-name"
+    DB_HOST = "db-host"
+
     # Project Registry Parameters
     CORE_API_URL = 'core-api-url'
     SSL_VERIFY = 'ssl_verify'
@@ -139,6 +150,9 @@ class Config:
     def get_logger_file(self) -> str:
         return self._get_config_from_section(self.SECTION_LOGGING, self.LOG_FILE)
 
+    def get_metrics_log_file(self) -> str:
+        return self._get_config_from_section(self.SECTION_LOGGING, self.METRICS_LOG_FILE)
+
     def get_logger_level(self) -> str:
         return self._get_config_from_section(self.SECTION_LOGGING, self.LOG_LEVEL)
 
@@ -238,3 +252,24 @@ class Config:
         providers[provider]['revoke_uri'] = self.get_oauth_revoke_url()
 
         return providers
+
+    def get_database_name(self) -> str:
+        return self._get_config_from_section(section_name=self.SECTION_DATABASE, parameter_name=self.DB_NAME)
+
+    def get_database_user(self) -> str:
+        return self._get_config_from_section(section_name=self.SECTION_DATABASE, parameter_name=self.DB_USER)
+
+    def get_database_password(self) -> str:
+        return self._get_config_from_section(section_name=self.SECTION_DATABASE, parameter_name=self.DB_PASSWORD)
+
+    def get_database_host(self) -> str:
+        return self._get_config_from_section(section_name=self.SECTION_DATABASE, parameter_name=self.DB_HOST)
+
+    def get_max_llt_per_project(self) -> int:
+        return int(self._get_config_from_section(self.SECTION_RUNTIME, self.MAX_LLT_CNT_PER_PROJECT))
+
+    def get_facility_operator_role(self) -> str:
+        return self._get_config_from_section(self.SECTION_RUNTIME, self.FACILITY_OPERATOR_ROLE)
+
+    def get_llt_role_suffix(self) -> str:
+        return self._get_config_from_section(self.SECTION_RUNTIME, self.LLT_ROLE_SUFFIX)
